def create(values = None):
  record = {
    "sampleId": None,
    "patientId": None,
    "tumorContent": None,
    "disease": None,
    "diseaseOntology": None,
    "detailedDisease": None,
    "detailedDiseaseOntology": None,
    "alternativeDiseaseSystems": None,
    "indication": None,
    "sourceType": None,
    "specimenType": None,
    "specimenId": None,
    "age": None
  }
  if values!=None:
    record.update(values)
  return record


def create(values = None):
  record = {
    "patientId": None,
    "mrnFacility": None,
    "gender": None,
    "race": None,
    "ethnicity": None,
    "dateOfBirth": None
  }
  if values!=None:
    record.update(values)
  return record


import setuptools

setuptools.setup(
  name="transmute-common",
  version="0.0.3",
  author="Adrian Flannery",
  author_email="aflannery@uabmc.edu",
  description="A package to support ETL creation within Transmute",
  url="https://github.com/finnor/transmute-common-py",
  packages=setuptools.find_packages(),
  classifiers=[
      "Programming Language :: Python :: 3",
      "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
      "Operating System :: OS Independent",
  ],
  python_requires='>=3.6',
)